@@ -3,7 +3,7 @@ from epub_conversion.wiki_decoder import almost_smart_open
 from .utils import line_converter
 from .dump_result import DumpResult
 
-def parse_dump(path, max_articles = 1000):
+def parse_dump(path, max_articles = 1000, report_every = 100, clear_output = False):
 	"""
 	Convert a dump to a set of articles with their
 	text tokenized and the intrawiki links separated and
@@ -32,6 +32,8 @@ def parse_dump(path, max_articles = 1000):
 	for line, article_name, links in convert_wiki_to_lines(
 		wiki,
 		max_articles = max_articles,
+		clear_output = clear_output,
+		report_every = report_every,
 		line_converter = line_converter):
 			result.observe_line(line, article_name, links)
 
